import { Entity } from '@alephdata/followthemoney';
import { Vertex } from './Vertex';
import { Edge } from './Edge';
import { Grouping } from './Grouping';
import { Point } from './Point';
import { Rectangle } from './Rectangle';
import { ISettingsData, Settings } from './Settings';
import { GraphConfig } from 'NetworkDiagram/GraphConfig';
export interface IGraphLayoutData {
    vertices: Array<any>;
    edges: Array<any>;
    groupings?: Array<any>;
    selection?: Array<string>;
    settings: ISettingsData;
}
export declare type VertexPredicate = (vertex: Vertex) => boolean;
export declare type GraphElement = Vertex | Edge;
export declare class GraphLayout {
    readonly config: GraphConfig;
    vertices: Map<string, Vertex>;
    edges: Map<string, Edge>;
    groupings: Map<string, Grouping>;
    selection: string[];
    settings: Settings;
    private hasDraggedSelection;
    constructor(config: GraphConfig);
    getVertices(): Vertex[];
    getEdges(): Edge[];
    getGroupings(): Grouping[];
    getSelectedVertices(): Vertex[];
    getSelectedEdges(): Edge[];
    getSelectedGroupings(): Grouping[];
    getSelectedEntityIds(): string[];
    addVertex(vertex: Vertex): Vertex;
    addEdge(edge: Edge): Edge;
    getVisibleElementCount(): any;
    private generate;
    addGrouping(grouping: Grouping): void;
    getVertexByEntity(entity: Entity): Vertex | undefined;
    selectElement(element: GraphElement | Array<GraphElement>, options?: any): void;
    selectVerticesByFilter(predicate: VertexPredicate, options?: any): void;
    selectByEntityIds(entityIds: Array<string>, options?: any): void;
    selectArea(area: Rectangle): void;
    getEntityIds(...elements: Array<GraphElement>): Array<string>;
    getHighlightedEdges(): Edge[];
    getSelectionAdjacentEdges(): Edge[];
    getAdjacentEdges(vertices: Array<string>): Edge[];
    hasSelection(): boolean;
    clearSelection(): void;
    isElementSelected: (element: GraphElement | Array<GraphElement>) => boolean;
    isGroupingSelected(grouping: Grouping): boolean;
    isGroupingMemberSelected(grouping: Grouping): boolean;
    isEdgeHighlighted(edge: Edge): boolean;
    isEdgeAdjacent(edge: Edge, vIds: Array<string>): boolean;
    applyPositioning(positioningFuncs: any, vertices: Array<Vertex>, maintainFixed?: boolean): this;
    dragSelection(offset: Point, initialPosition?: Point): void;
    dragEdge(edge: Edge, offset: Point, initialPosition?: Point): void;
    removeSubgroups(): void;
    removeSelection(): string[];
    dropSelection(): true | undefined;
    ungroupSelection(): void;
    addVertexToGroupings(vertex: Vertex): void;
    getVisibleVertexRect(): Rectangle;
    layout(entities: Array<Entity>, center?: Point): void;
    clone(): GraphLayout;
    update(withData: IGraphLayoutData): GraphLayout;
    toJSON(): IGraphLayoutData;
    static fromJSON(config: GraphConfig, data: IGraphLayoutData): GraphLayout;
}
