import { Entity, Model, Namespace, Schema, IEntityDatum } from '@alephdata/followthemoney';
import { EntityChanges } from 'components/common/types';
export interface IEntityManagerProps {
    model?: Model;
    entities: Array<IEntityDatum>;
    namespace?: Namespace;
    createEntity?: (entity: IEntityDatum, local?: boolean) => Entity;
    updateEntity?: (entity: Entity) => void;
    deleteEntity?: (entityId: string) => void;
    expandEntity?: (entityId: string, properties?: Array<string>, limit?: number) => Promise<any>;
    getEntitySuggestions?: (queryText: string, schemata?: Array<Schema>) => Promise<Entity[]>;
    resolveEntityReference?: (entityId: string) => Entity | undefined;
}
export declare class EntityManager {
    readonly model: Model;
    readonly namespace?: Namespace;
    readonly hasExpand: boolean;
    readonly hasSuggest: boolean;
    entities: Map<string, Entity>;
    private overload;
    constructor(props?: IEntityManagerProps);
    createEntity(entityData: any, local?: boolean): Entity;
    getEntities(ids?: Array<string>): Entity[];
    getThingEntities(): Entity[];
    getEntity(entityId: string): Entity | undefined;
    hasEntity(entity: Entity): boolean;
    addEntities(entities: Array<Entity>): void;
    updateEntity(entity: Entity): Entity;
    deleteEntities(entityIds: Array<string>): void;
    expandEntity(entityId: string, properties?: Array<string>, limit?: number): Promise<any>;
    resolveEntityReference(entityId: string): any;
    getEntitySuggestions(local: boolean, queryText: string, schemata?: Array<Schema>): Promise<any>;
    applyEntityChanges(entityChanges: EntityChanges, factor: number): void;
    toJSON(): Array<IEntityDatum>;
    static fromJSON(props: any, entitiesData: Array<IEntityDatum>): EntityManager;
}
